# Glia bundle - dbbs_mod_collection

This package contains assets for the NEURON simulator, generated by Astrocyte.

This package is best installed using Glia:

    glia install dbbs-mod-collection

These models were made publicly available by Robin De Schepper, copyright notices can be
found in the individual mod files.
